"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BullMonitor = void 0;
const data_sources_1 = require("./gql/data-sources");
const type_defs_1 = require("./gql/type-defs");
const resolvers_1 = require("./gql/resolvers");
const ui_1 = require("./ui");
class BullMonitor {
    constructor(config) {
        this._defaultConfig = {
            queues: [],
            baseUrl: '',
            gqlPlayground: true,
        };
        this.gqlBasePath = '/graphql';
        this.config = Object.assign(Object.assign({}, this._defaultConfig), config);
        this.ui = new ui_1.UI();
    }
    createServer(Server) {
        this.server = new Server({
            typeDefs: type_defs_1.typeDefs,
            // @ts-ignore
            resolvers: resolvers_1.resolvers,
            playground: this.config.gqlPlayground,
            dataSources: () => ({
                bull: new data_sources_1.BullDataSource(this.config.queues),
            }),
        });
    }
    async startServer() {
        return await this.server.start();
    }
    renderUi() {
        return this.ui.render();
    }
    get baseUrl() {
        return this.config.baseUrl;
    }
    get uiEndpoint() {
        return this.baseUrl || '/';
    }
    get gqlEndpoint() {
        const base = this.baseUrl;
        if (!base) {
            return this.gqlBasePath;
        }
        else if (base.endsWith('/')) {
            return base.slice(0, -1) + this.gqlBasePath;
        }
        return base + this.gqlBasePath;
    }
}
exports.BullMonitor = BullMonitor;
//# sourceMappingURL=index.js.map